[Libreoffice-commits] core.git: 2 commits - slideshow/source

David Tardon dtardon at redhat.com
Mon Oct 31 19:22:50 UTC 2016


 slideshow/source/engine/opengl/Operation.cxx |    8 +++++---
 slideshow/source/engine/opengl/Operation.hxx |    4 ++--
 2 files changed, 7 insertions(+), 5 deletions(-)

New commits:
commit 04055cd8d9fcff67513cfd7de0872cb48bc82967
Author: David Tardon <dtardon at redhat.com>
Date:   Mon Oct 31 20:13:36 2016 +0100

    fix doc comment to match code
    
    This has been wrong since the initial commit...
    
    Change-Id: I271375ba10c37aa9b198476955d66af9fc019e27

diff --git a/slideshow/source/engine/opengl/Operation.cxx b/slideshow/source/engine/opengl/Operation.cxx
index 0888d6a..a8f5bc8 100644
--- a/slideshow/source/engine/opengl/Operation.cxx
+++ b/slideshow/source/engine/opengl/Operation.cxx
@@ -31,6 +31,8 @@
 #include <glm/gtc/matrix_transform.hpp>
 #include <glm/gtc/type_ptr.hpp>
 
+#include <basegfx/numeric/ftools.hxx>
+
 #include "Operation.hxx"
 
 SRotate::SRotate(const glm::vec3& Axis, const glm::vec3& Origin,
@@ -38,7 +40,7 @@ SRotate::SRotate(const glm::vec3& Axis, const glm::vec3& Origin,
     Operation(bInter, T0, T1),
     axis(Axis),
     origin(Origin),
-    angle(Angle)
+    angle(basegfx::deg2rad(Angle))
 {
 }
 
@@ -55,7 +57,7 @@ RotateAndScaleDepthByWidth::RotateAndScaleDepthByWidth(const glm::vec3& Axis,
     Operation(bInter, T0, T1),
     axis(Axis),
     origin(Origin),
-    angle(Angle),
+    angle(basegfx::deg2rad(Angle)),
     scale(bScale)
 {
 }
@@ -65,7 +67,7 @@ RotateAndScaleDepthByHeight::RotateAndScaleDepthByHeight(const glm::vec3& Axis,
     Operation(bInter, T0, T1),
     axis(Axis),
     origin(Origin),
-    angle(Angle),
+    angle(basegfx::deg2rad(Angle)),
     scale(bScale)
 {
 }


More information about the Libreoffice-commits mailing list
diff --git a/slideshow/source/engine/opengl/Operation.hxx b/slideshow/source/engine/opengl/Operation.hxx
index 12d0a48..95aaa06 100644
--- a/slideshow/source/engine/opengl/Operation.hxx
+++ b/slideshow/source/engine/opengl/Operation.hxx
@@ -90,7 +90,7 @@ public:
         position that rotation axis runs through
 
         @param Angle
-        angle in radians of CCW rotation
+        angle in degrees of CCW rotation
 
         @param bInter
         see Operation
@@ -114,7 +114,7 @@ private:
     */
     glm::vec3 origin;
 
     /** angle in radians of CCW rotation
     */
     double angle;
 };
@@ -114,7 +114,7 @@ private:
     glm::vec3 origin;
 
-    /** angle in radians of CCW rotation
+    /** angle in degrees of CCW rotation
     */
     double angle;
commit 7445399af829c48e8c71eed66f132d96fa195c37
Author: David Tardon <dtardon at redhat.com>
Date:   Mon Oct 31 19:51:56 2016 +0100

    convert angle from degrees to radians for glm
    
    This makes simple (i.e., not implemented as a shader) OpenGL transitions
    work correctly again.
    
    Change-Id: I773f686089bce3611940743b1a7f5046093886e8
